@@ -30,6 +30,7 @@ from skopt.utils import use_named_args
 # types
 import skopt.learning.gaussian_process.kernels as Kernel
 from typing import List, Callable, Iterable, Union
+from pandas import DataFrame
 
 
 @dataclass
@@ -160,7 +161,7 @@ class BayesianOptimizer:
         self,
         model,
         hyperparameterSpaces: Iterable[Space],
-        trainingData,
+        inputData,
         trainingLabels,
         objectiveToMinimize: Callable,
         pointSampleCount: int = cpu_count(),
@@ -191,13 +192,17 @@ class BayesianOptimizer:
                         for label in np.unique(trainingLabels)
                     ]
                 )
-                balancedData = trainingData[balancedLabelMask]
+                balancedData = (
+                    inputData[balancedLabelMask]
+                    if not isinstance(inputData, DataFrame)
+                    else inputData.iloc[balancedLabelMask]
+                )
                 balancedLabels = trainingLabels[balancedLabelMask]
                 loadedObjective = partial(
                     objectiveToMinimize,
                     **{
                         "model": model,
-                        "trainingData": balancedData,
+                        "inputData": balancedData,
                         "trainingLabels": balancedLabels,
                     },
                 )
